==> protonsdk-0.7.0-sources.jar: com/metallicus/protonsdk/repository/ESRRepository.kt <==
/*
 * Copyright (c) 2020 Proton Chain LLC, Delaware
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.metallicus.protonsdk.repository

import com.google.gson.JsonObject
import com.metallicus.protonsdk.api.*
import retrofit2.Response
import javax.inject.Inject
import javax.inject.Singleton

@Singleton
class ESRRepository @Inject constructor(
	private val esrCallbackService: ESRCallbackService
) {
	suspend fun cancelAuthorizeESR(url: String, error: String): Response<String> {
		return esrCallbackService.cancelAuthorizeESR(url, CancelAuthorizeESRBody(error))
	}

	suspend fun authorizeESR(url: String, error: String): Response<JsonObject> {
		return esrCallbackService.authorizeESR(url, AuthorizeESRBody(error))
	}
}

==> protonsdk-0.7.1-sources.jar: com/metallicus/protonsdk/repository/ESRRepository.kt <==
/*
 * Copyright (c) 2020 Proton Chain LLC, Delaware
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.metallicus.protonsdk.repository

import com.metallicus.protonsdk.api.*
import retrofit2.Response
import javax.inject.Inject
import javax.inject.Singleton

@Singleton
class ESRRepository @Inject constructor(
	private val esrCallbackService: ESRCallbackService
) {
	suspend fun cancelAuthorizeESR(url: String, error: String): Response<String> {
		return esrCallbackService.cancelAuthorizeESR(url, CancelAuthorizeESRBody(error))
	}

	suspend fun authorizeESR(url: String, params: Map<String, String>): Response<String> {
		return esrCallbackService.authorizeESR(url, params)
	}
}
